import fs from 'node:fs/promises';
import path from 'node:path';
import { createRendererUrl, pickRendererUrl, removeFixtureNameExtension, removeFixtureNameSuffix, } from 'react-cosmos-core';
import { findUserModulePaths } from '../userModules/findUserModulePaths.js';
import { importKeyPath } from '../userModules/shared.js';
export const fixturesJsonPlugin = {
    name: 'fixturesJson',
    devServer({ cosmosConfig, expressApp }) {
        expressApp.get('/cosmos.fixtures.json', (req, res) => {
            res.json(createFixtureItems(cosmosConfig, 'dev'));
        });
    },
    async export({ cosmosConfig }) {
        const { exportPath } = cosmosConfig;
        const json = createFixtureItems(cosmosConfig, 'export');
        await fs.writeFile(path.join(exportPath, 'cosmos.fixtures.json'), JSON.stringify(json, null, 2));
    },
};
function createFixtureItems(cosmosConfig, command) {
    const rendererUrl = pickRendererUrl(cosmosConfig.rendererUrl, command);
    if (!rendererUrl) {
        return {
            rendererUrl: null,
            fixtures: [],
        };
    }
    const { fixturesDir, fixtureFileSuffix } = cosmosConfig;
    const { fixturePaths } = findUserModulePaths(cosmosConfig);
    return {
        rendererUrl,
        fixtures: fixturePaths.map(filePath => {
            const relPath = importKeyPath(filePath, cosmosConfig.rootDir);
            const fixtureId = { path: relPath };
            return {
                filePath: relPath,
                cleanPath: cleanFixturePath(relPath, fixturesDir, fixtureFileSuffix),
                rendererUrl: createRendererUrl(rendererUrl, fixtureId, true),
            };
        }),
    };
}
function cleanFixturePath(filePath, fixturesDir, fixtureSuffix) {
    const paths = filePath.split('/').filter(p => p !== fixturesDir);
    return [
        ...paths.slice(0, -1),
        removeFixtureNameSuffix(removeFixtureNameExtension(paths[paths.length - 1]), fixtureSuffix),
    ];
}
